# <img src='./ui/soundcloud.png' width='50' height='50' style='vertical-align:bottom'/> Soundcloud Skill

soundcloud skill for OCP

## About

search soundcloud by voice!

![](./gui.png)

## Examples
* "play piratech in soundcloud"
* "play piratech nuclear chill"

## Credits
JarbasAl

## Category
**Entertainment**

## Tags
- soundcloud
- OCP
- common play
- music
